@@ -6,11 +6,12 @@
   /**
    * @ngInject
    */
-  MessageEditorController.$inject = ['$scope', '$window', '$stateParams', '$mdConstant', '$mdUtil', '$mdDialog', '$mdToast', 'FileUploader', 'stateAccount', 'stateMessage', 'onCompletePromise', 'encodeUriFilter', '$timeout', 'sgFocus', 'Dialog', 'AddressBook', 'Card', 'Preferences'];
-  function MessageEditorController($scope, $window, $stateParams, $mdConstant, $mdUtil, $mdDialog, $mdToast, FileUploader, stateAccount, stateMessage, onCompletePromise, encodeUriFilter, $timeout, focus, Dialog, AddressBook, Card, Preferences) {
+  MessageEditorController.$inject = ['$scope', '$window', '$stateParams', '$mdConstant', '$mdUtil', '$mdDialog', '$mdToast', 'FileUploader', 'stateParent', 'stateAccount', 'stateMessage', 'onCompletePromise', 'encodeUriFilter', '$timeout', 'sgFocus', 'Dialog', 'AddressBook', 'Card', 'Preferences'];
+  function MessageEditorController($scope, $window, $stateParams, $mdConstant, $mdUtil, $mdDialog, $mdToast, FileUploader, stateParent, stateAccount, stateMessage, onCompletePromise, encodeUriFilter, $timeout, focus, Dialog, AddressBook, Card, Preferences) {
     var vm = this;
 
     this.$onInit = function() {
+      $scope.isPopup = stateParent.isPopup;
       vm.addRecipient = addRecipient;
       vm.autocomplete = {to: {}, cc: {}, bcc: {}};
       vm.autosave = null;
@@ -127,7 +128,7 @@
         // },
         onSuccessItem: function(item, response, status, headers) {
           vm.message.$setUID(response.uid);
-          vm.message.$reload({asDraft: false});
+          vm.message.$reload();
           item.inlineUrl = response.lastAttachmentAttrs[0].url;
           //console.debug(item); console.debug('success = ' + JSON.stringify(response, undefined, 2));
         },
@@ -297,7 +298,8 @@
                contact.charCodeAt(i) == 32 ||   // space
                contact.charCodeAt(i) == 44 ||   // ,
                contact.charCodeAt(i) == 59) &&  // ;
-              emailRE.test(address)) {
+              emailRE.test(address) &&
+              recipients.indexOf(address) < 0) {
             recipients.push(address);
             address = '';
           }
@@ -305,8 +307,9 @@
             address += contact.charAt(i);
           }
         }
-        if (address)
+        if (address && recipients.indexOf(address) < 0)
           recipients.push(address);
+
         return null;
       }
 
@@ -314,7 +317,7 @@
         // If the list's members were already fetch, use them
         if (angular.isDefined(contact.refs) && contact.refs.length) {
           _.forEach(contact.refs, function(ref) {
-            if (ref.email.length)
+            if (ref.email.length && recipients.indexOf(ref.$shortFormat()) < 0)
               recipients.push(ref.$shortFormat());
           });
         }
@@ -322,7 +325,7 @@
           list = Card.$find(contact.container, contact.c_name);
           list.$id().then(function(listId) {
             _.forEach(list.refs, function(ref) {
-              if (ref.email.length)
+              if (ref.email.length && recipients.indexOf(ref.$shortFormat()) < 0)
                 recipients.push(ref.$shortFormat());
             });
           });
